package com.tzld.piaoquan.recommend.server.service.filter;

import com.tzld.piaoquan.recommend.server.service.PreViewedService;
import com.tzld.piaoquan.recommend.server.service.ViewedService;
import com.tzld.piaoquan.recommend.server.util.JSONUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @author dyp
 */
@Slf4j
public abstract class AbstractFilterService implements FilterService {
    @Autowired
    private PreViewedService preViewedService;

    @Autowired
    private ViewedService viewedService;

    protected List<Long> viewFilter(FilterParam param) {
        log.info("filterParam={}", JSONUtils.toJson(param));
        List<Long> videoIds = filterByPreViewed(param.getAppType(), param.getMid(), param.getVideoIds());
        log.info("filterByPreViewed videoIds={}", JSONUtils.toJson(videoIds));
        videoIds = filterByViewed(param.getAppType(), param.getMid(), param.getUid(), videoIds);
        log.info("filterByViewed videoIds={}", JSONUtils.toJson(videoIds));
        return videoIds;
    }

    private List<Long> filterByViewed(int appType, String mid, String uid, List<Long> videoIds) {
        // TODO uid为空时，还需要过滤么？
        if (StringUtils.isBlank(mid)
                || CollectionUtils.isEmpty(videoIds)) {
            return videoIds;
        }
        return viewedService.filterViewedVideo(appType, mid, uid, videoIds);

    }

    private List<Long> filterByPreViewed(int appType, String mid, List<Long> videoIds) {

        if (StringUtils.isBlank(mid)) {
            return videoIds;
        }
        Set<Long> preViewedVideoIds = preViewedService.getVideoIds(appType, mid);
        log.info("preViewedService.getVideoIds preViewedVideoIds={}, appType={}, mid={}",
                JSONUtils.toJson(preViewedVideoIds), appType, mid);
        return videoIds.stream()
                .filter(l -> !preViewedVideoIds.contains(l))
                .collect(Collectors.toList());

    }
}
